InspectData

Trait InspectData 

pub trait InspectData<T> {
    // Required method
    fn new(object: &T, inspect: Node) -> Self;
}
Represents inspect data that is tied to a specific object. This inspect data and the object of type T should always be bundled together.

Required Methods

fn new(object: &T, inspect: Node) -> Self

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl InspectData<BondingData> for BondingDataInspect

Available on Fuchsia only.
Source

impl InspectData<HostInfo> for HostInfoInspect

Available on Fuchsia only.
Source

impl<T, I: ImmutableDataInspect<T>> InspectData<T> for I

Available on Fuchsia only.